@@ -1,4 +1,4 @@
-# Copyright © 2015 Piotr Ożarowski <piotr@debian.org>
+# Copyright © 2015-2018 Piotr Ożarowski <piotr@debian.org>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -55,7 +55,8 @@ def get_pypi_info(name, version=None):
             return
         return result
     finally:
-        session is not None and session.close()
+        if session is not None:
+            yield from session.close()
 
 
 def parse_pypi_info(data):
@@ -113,6 +114,7 @@ def parse_pkg_info(fpath):
     raise NotImplementedError()  # FIXME
 
 
+@asyncio.coroutine
 def download(name, version=None, destdir='.'):
     details = yield from get_pypi_info(name, version)
     if not details:
@@ -151,7 +153,8 @@ def download(name, version=None, destdir='.'):
             data = yield from response.read()
             fp.write(data)
     finally:
-        session is not None and session.close()
+        if session is not None:
+            yield from session.close()
 
     if orig_ext != ext:
         cmd = ['mk-origtargz', '--rename', '--compression', 'xz',
